@@ -1,3 +1,10 @@
+"""
+    spider 基类
+
+    注意：要明白类的赋值操作、修改操作的概念
+    赋值操作：给类本身进行赋值
+    修改操作：类本身赋值后，是基于类本身修改，类本身未赋值，那么就会向父类进行查找，修改的就是父类
+"""
 import sys
 import time
 import types
@@ -155,7 +162,7 @@ class SpiderBase(threading.Thread):
             if len(self.distribute_thread_list) == 0:
                 break
 
-            time.sleep(0.5)
+            time.sleep(0.1)
 
     def wait_spider_controller_done(self) -> None:
         """
@@ -171,7 +178,7 @@ class SpiderBase(threading.Thread):
             elif self.all_spider_controller_is_done():
                 break
 
-            time.sleep(0.5)  # 不加延迟将会导致性能问题
+            time.sleep(0.1)  # 不加延迟将会导致性能问题
 
     def wait_item_controller_done(self) -> None:
         """
@@ -187,7 +194,7 @@ class SpiderBase(threading.Thread):
             if len(self.item_controller_list) == 0:
                 break
 
-            time.sleep(0.5)
+            time.sleep(0.1)
 
     def stop_all_spider_controller(self) -> None:
         """
@@ -202,7 +209,7 @@ class SpiderBase(threading.Thread):
             if self.all_spider_controller_is_done():
                 break
 
-            time.sleep(0.5)
+            time.sleep(0.1)
 
     def all_distribute_thread_is_done(self) -> bool:
         """
@@ -331,6 +338,18 @@ class SpiderBase(threading.Thread):
         """
         self.__dict__[key] = value
 
+    def __getattr__(self, key):
+        """
+        获取属性
+
+        :param key:
+        :return:
+        """
+        if key not in self.__dict__:
+            raise AttributeError(f"'{self.__class__.__name__}' object has no attribute '{key}'")
+
+        return self.__dict__[key]
+
 
 class Spider(SpiderBase):
     """
